package com.fs.his.service;

import java.util.List;
import com.fs.his.domain.FsIcd;

/**
 * icd编码库Service接口
 *
 * @author fs
 * @date 2024-04-22
 */
public interface IFsIcdService
{
    /**
     * 查询icd编码库
     *
     * @param id icd编码库主键
     * @return icd编码库
     */
    public FsIcd selectFsIcdById(Long id);

    /**
     * 查询icd编码库列表
     *
     * @param fsIcd icd编码库
     * @return icd编码库集合
     */
    public List<FsIcd> selectFsIcdList(FsIcd fsIcd);

    /**
     * 新增icd编码库
     *
     * @param fsIcd icd编码库
     * @return 结果
     */
    public int insertFsIcd(FsIcd fsIcd);

    /**
     * 修改icd编码库
     *
     * @param fsIcd icd编码库
     * @return 结果
     */
    public int updateFsIcd(FsIcd fsIcd);

    /**
     * 批量删除icd编码库
     *
     * @param ids 需要删除的icd编码库主键集合
     * @return 结果
     */
    public int deleteFsIcdByIds(Long[] ids);

    /**
     * 删除icd编码库信息
     *
     * @param id icd编码库主键
     * @return 结果
     */
    public int deleteFsIcdById(Long id);

    String importData(List<FsIcd> list);

    List<FsIcd> selectFsIcdByName(String name);
}
